@@ -2,6 +2,8 @@
  *  joydump.c  Version 1.2
  *
  *  Copyright (c) 1996-1999 Vojtech Pavlik
+ *
+ *  Sponsored by SuSE
  */
 
 /*
@@ -25,7 +27,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  * 
  * Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
  * Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
  */
 
@@ -38,7 +40,7 @@
 #include <linux/kernel.h>
 #include <linux/delay.h>
 
-MODULE_AUTHOR("Vojtech Pavlik <vojtech@ucw.cz>");
+MODULE_AUTHOR("Vojtech Pavlik <vojtech@suse.cz>");
 
 #define JS_PORT 0x201
 
@@ -57,7 +59,7 @@ static unsigned long dumptime = 0;
 #define GET_TIME(x)	do { x = dumptime++; } while(0)
 #endif
 
-#define BUF_SIZE 128
+#define BUF_SIZE 256
 
 struct datatype {
 	unsigned int time;
@@ -112,7 +114,7 @@ int init_module(void)
 	printk(KERN_INFO "joydump: | I/O at %#x takes %d.%02d us.                |\n",
 		JS_PORT, (t1 - t) / div / 10, (t1 - t) * 10 / div % 100);
 
-	timeout *= 20;
+	timeout *= 40;
 
 /*
  * Gather data.
