@@ -2,6 +2,8 @@
  * jscal.c  Version 1.2
  *
  * Copyright (c) 1997-199 Vojtech Pavlik
+ *
+ * Sponsored by SuSE
  */
 
 /*
@@ -24,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
  * Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
  */
 
@@ -35,7 +37,7 @@
 #include <stdio.h>
 #include <math.h>
 #include <getopt.h>
-#include <strings.h>
+#include <string.h>
 #include <fcntl.h>
 
 #include <asm/param.h>
@@ -152,12 +154,14 @@ void help(void)
 	puts("Usage: jscal <device>");
 	putchar('\n');
 	puts("  -c             --calibrate         Calibrate the joystick");
-	puts("  -h             --help              This help screen");
-	puts("  -s <x,y,z...>  --set-correction    Sets correction to specific values");
+	puts("  -h             --help              Display this help");
+	puts("  -s <x,y,z...>  --set-correction    Sets correction to specified values");
 	puts("  -t             --test-center       Tests if joystick is corectly calibrated");
-	puts("                                       returns 1 if axes are wrong and 2 if buttons");
+	puts("                                       returns 0 on success, see the jscal");
+	puts("                                       manpage for error values");
 	puts("  -V             --version           Prints the version numbers");
-	puts("  -p             --print-correction  Prints the current settings as a jscal command line");
+	puts("  -p             --print-correction  Prints the current settings as a jscal");
+	puts("                                       command line");
 	putchar('\n');
 }
 
@@ -262,7 +266,7 @@ void calibrate()
 		putcs("Hold ... ");
 
 		corda[j].cmin[i] = js.axis[j];
-		corda[j].cmax[i] = 0;
+		corda[j].cmax[i] = js.axis[j];
 
 		t = get_time();
 
@@ -520,6 +524,7 @@ int main(int argc, char **argv)
 	}
 	if (version != JS_VERSION) {
 		fprintf(stderr, "jscal: wrong version\n");
+		print_version();
 		exit(1);
 	}
 
